@@ -145,3 +145,12 @@ class NodeGroupTemplateTest(base.BaseTestCase):
         self.assertEqual(update_url, self.responses.last_request.url)
         self.assertEqual(unset_json,
                          json.loads(self.responses.last_request.body))
+
+    def test_node_group_template_export(self):
+        url = self.URL + '/node-group-templates/id/export'
+        self.responses.get(url, json={'node_group_template': self.body})
+        resp = self.client.node_group_templates.export('id')
+
+        self.assertEqual(url, self.responses.last_request.url)
+        self.assertIsInstance(resp, ng.NodeGroupTemplate)
+        self.assertDictsEqual(self.body, resp.__dict__[u'node_group_template'])
